==> taomu-job-server-0.0.15.3-sources.jar: cool/taomu/box/job/server/controller/entity/HtmlTemplateEntity.java <==
package cool.taomu.box.job.server.controller.entity;

import java.io.Serializable;
import java.util.List;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtend.lib.annotations.ToString;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

@Accessors
@ToString
@SuppressWarnings("all")
public class HtmlTemplateEntity implements Serializable {
  @Accessors
  @ToString
  public static class DataEntity implements Serializable {
    private String analysisShellText;
    
    private String mustacheText;
    
    private String resultPath;
    
    private String name;
    
    private String pname;
    
    @Pure
    public String getAnalysisShellText() {
      return this.analysisShellText;
    }
    
    public void setAnalysisShellText(final String analysisShellText) {
      this.analysisShellText = analysisShellText;
    }
    
    @Pure
    public String getMustacheText() {
      return this.mustacheText;
    }
    
    public void setMustacheText(final String mustacheText) {
      this.mustacheText = mustacheText;
    }
    
    @Pure
    public String getResultPath() {
      return this.resultPath;
    }
    
    public void setResultPath(final String resultPath) {
      this.resultPath = resultPath;
    }
    
    @Pure
    public String getName() {
      return this.name;
    }
    
    public void setName(final String name) {
      this.name = name;
    }
    
    @Pure
    public String getPname() {
      return this.pname;
    }
    
    public void setPname(final String pname) {
      this.pname = pname;
    }
    
    @Override
    @Pure
    public String toString() {
      ToStringBuilder b = new ToStringBuilder(this);
      b.add("analysisShellText", this.analysisShellText);
      b.add("mustacheText", this.mustacheText);
      b.add("resultPath", this.resultPath);
      b.add("name", this.name);
      b.add("pname", this.pname);
      return b.toString();
    }
  }
  
  private List<HtmlTemplateEntity.DataEntity> data;
  
  @Pure
  public List<HtmlTemplateEntity.DataEntity> getData() {
    return this.data;
  }
  
  public void setData(final List<HtmlTemplateEntity.DataEntity> data) {
    this.data = data;
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("data", this.data);
    return b.toString();
  }
}

==> taomu-job-server-0.0.16-sources.jar: cool/taomu/box/job/server/controller/entity/HtmlTemplateEntity.java <==
package cool.taomu.box.job.server.controller.entity;

import java.io.Serializable;
import java.util.List;
import org.eclipse.xtend.lib.annotations.Accessors;
import org.eclipse.xtend.lib.annotations.ToString;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

@Accessors
@ToString
@SuppressWarnings("all")
public class HtmlTemplateEntity implements Serializable {
  @Accessors
  @ToString
  public static class DataEntity implements Serializable {
    private String analysisShellText;
    
    private String analysisShellPath;
    
    private String mustachePath;
    
    private String mustacheText;
    
    private String resultPath;
    
    private String resultText;
    
    private String name;
    
    private String pname;
    
    @Pure
    public String getAnalysisShellText() {
      return this.analysisShellText;
    }
    
    public void setAnalysisShellText(final String analysisShellText) {
      this.analysisShellText = analysisShellText;
    }
    
    @Pure
    public String getAnalysisShellPath() {
      return this.analysisShellPath;
    }
    
    public void setAnalysisShellPath(final String analysisShellPath) {
      this.analysisShellPath = analysisShellPath;
    }
    
    @Pure
    public String getMustachePath() {
      return this.mustachePath;
    }
    
    public void setMustachePath(final String mustachePath) {
      this.mustachePath = mustachePath;
    }
    
    @Pure
    public String getMustacheText() {
      return this.mustacheText;
    }
    
    public void setMustacheText(final String mustacheText) {
      this.mustacheText = mustacheText;
    }
    
    @Pure
    public String getResultPath() {
      return this.resultPath;
    }
    
    public void setResultPath(final String resultPath) {
      this.resultPath = resultPath;
    }
    
    @Pure
    public String getResultText() {
      return this.resultText;
    }
    
    public void setResultText(final String resultText) {
      this.resultText = resultText;
    }
    
    @Pure
    public String getName() {
      return this.name;
    }
    
    public void setName(final String name) {
      this.name = name;
    }
    
    @Pure
    public String getPname() {
      return this.pname;
    }
    
    public void setPname(final String pname) {
      this.pname = pname;
    }
    
    @Override
    @Pure
    public String toString() {
      ToStringBuilder b = new ToStringBuilder(this);
      b.add("analysisShellText", this.analysisShellText);
      b.add("analysisShellPath", this.analysisShellPath);
      b.add("mustachePath", this.mustachePath);
      b.add("mustacheText", this.mustacheText);
      b.add("resultPath", this.resultPath);
      b.add("resultText", this.resultText);
      b.add("name", this.name);
      b.add("pname", this.pname);
      return b.toString();
    }
  }
  
  private List<HtmlTemplateEntity.DataEntity> data;
  
  @Pure
  public List<HtmlTemplateEntity.DataEntity> getData() {
    return this.data;
  }
  
  public void setData(final List<HtmlTemplateEntity.DataEntity> data) {
    this.data = data;
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("data", this.data);
    return b.toString();
  }
}
